@@ -27,8 +27,9 @@
 #include "ka-gconf-tools.h"
 #include "ka-gconf.h"
 #include "ka-tools.h"
-#include "ka-tickets.h"
+#include "ka-main-window.h"
 #include "ka-plugin-loader.h"
+#include "ka-preferences.h"
 #include "ka-closures.h"
 #include <libnotify/notify.h>
 
@@ -56,6 +57,7 @@ const gchar *ka_signal_names[KA_SIGNAL_COUNT] = {
     "krb-tgt-acquired",
     "krb-tgt-renewed",
     "krb-tgt-expired",
+    "krb-ccache-changed",
 };
 
 
@@ -81,7 +83,7 @@ struct _KaAppletPrivate {
     gboolean ns_persistence;    /* does the notification server support persistence */
 
     KaPwDialog *pwdialog;       /* the password dialog */
-    int pw_prompt_secs;         /* when to start prompting for a password */
+    int pw_prompt_secs;         /* when to start sending notifications */
     KaPluginLoader *loader;     /* Plugin loader */
 
     NotifyNotification *notification;   /* notification messages */
@@ -318,8 +320,7 @@ ka_applet_class_init (KaAppletClass *klass)
                                   G_PARAM_CONSTRUCT | G_PARAM_READWRITE);
     g_object_class_install_property (object_class,
                                      KA_PROP_TGT_RENEWABLE, pspec);
-
-    for (i = 0; i < KA_SIGNAL_COUNT; i++) {
+    for (i=0; i < KA_SIGNAL_COUNT-1; i++) {
         guint signalId;
 
         signalId = g_signal_new (ka_signal_names[i], G_OBJECT_CLASS_TYPE (klass),
@@ -329,6 +330,12 @@ ka_applet_class_init (KaAppletClass *klass)
                                  G_TYPE_STRING, G_TYPE_UINT);
         klass->signals[i] = signalId;
     }
+    klass->signals[KA_CCACHE_CHANGED] = g_signal_new (
+        ka_signal_names[KA_CCACHE_CHANGED], 
+        G_OBJECT_CLASS_TYPE (klass),
+        G_SIGNAL_RUN_LAST, 0, NULL, NULL,
+        g_cclosure_marshal_VOID__VOID,
+        G_TYPE_NONE, 0);
 }
 
 
@@ -456,8 +463,8 @@ ka_notify_ticket_action_cb (NotifyNotification *notification G_GNUC_UNUSED,
         KA_DEBUG ("Removing ccache");
         ka_destroy_ccache (self);
     } else if (strcmp (action, "ka-list-tickets") == 0) {
-        KA_DEBUG ("Listing tickets");
-        ka_tickets_dialog_run ();
+        KA_DEBUG ("Showing main window");
+        ka_main_window_show ();
     } else {
         g_warning ("unkonwn action for callback");
     }
@@ -530,7 +537,7 @@ ka_send_event_notification (KaApplet *self,
     }
 
     notify_notification_clear_actions(notification);
-    /* Add List Tickets button until we moved this into cc-panl */
+
     if (self->priv->ns_persistence) {
         notify_notification_add_action (notification,
                                         "ka-list-tickets",
@@ -591,14 +598,14 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
     int remaining = expiry - now;
     static int last_warn = 0;
     static gboolean expiry_notified = FALSE;
+    static gboolean initial_notification = TRUE;
     static krb5_timestamp old_expiry = 0;
     gboolean notify = TRUE;
     const char *status_icon = ka_applet_select_icon (applet, remaining);
     char *tooltip_text = ka_applet_tooltip_text (remaining);
 
-
     if (remaining > 0) {
-        if (expiry_notified) {
+        if (expiry_notified || initial_notification) {
             const char* msg;
             ka_gconf_get_bool (applet->priv->gconf,
                                KA_GCONF_KEY_NOTIFY_VALID, &notify);
@@ -607,8 +614,12 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
 
                 if (applet->priv->krb_msg)
                     msg = applet->priv->krb_msg;
-                else
-                    msg = _("You've refreshed your Kerberos credentials.");
+                else {
+                    if (initial_notification)
+                        msg = _("You have valid Kerberos credentials.");
+                    else
+                        msg = _("You've refreshed your Kerberos credentials.");
+                }
                 ka_send_event_notification (applet,
                                             _("Network credentials valid"),
                                             msg,
@@ -661,6 +672,7 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
     old_expiry = expiry;
     ka_update_tray_icon(applet, status_icon, tooltip_text);
     g_free (tooltip_text);
+    initial_notification = FALSE;
     return 0;
 }
 
@@ -675,37 +687,10 @@ ka_applet_menu_add_separator_item (GtkWidget *menu)
     gtk_widget_show (menu_item);
 }
 
-static void
-ka_applet_cb_preferences (GtkWidget *menuitem G_GNUC_UNUSED,
-                          gpointer user_data G_GNUC_UNUSED)
-{
-    GError *error = NULL;
-
-    g_spawn_command_line_async (BIN_DIR
-                                G_DIR_SEPARATOR_S
-                                "gnome-control-center ka-panel", &error);
-    if (error) {
-        GtkWidget *message_dialog;
-
-        message_dialog = gtk_message_dialog_new (NULL,
-                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                 GTK_MESSAGE_ERROR,
-                                                 GTK_BUTTONS_CLOSE,
-                                                 _("There was an error launching the preferences dialog: %s"),
-                                                 error->message);
-        gtk_window_set_resizable (GTK_WINDOW (message_dialog), FALSE);
-
-        g_signal_connect (message_dialog, "response",
-                          G_CALLBACK (gtk_widget_destroy), NULL);
-        gtk_widget_show (message_dialog);
-        g_clear_error (&error);
-    }
-}
-
 
 /* Free all resources and quit */
 static void
-ka_applet_cb_quit (GtkMenuItem *menuitem G_GNUC_UNUSED, gpointer user_data)
+ka_applet_quit_cb (GtkMenuItem *menuitem G_GNUC_UNUSED, gpointer user_data)
 {
     KaApplet *applet = KA_APPLET (user_data);
 
@@ -714,36 +699,7 @@ ka_applet_cb_quit (GtkMenuItem *menuitem G_GNUC_UNUSED, gpointer user_data)
 
 
 static void
-ka_applet_cb_about_dialog (GtkMenuItem *menuitem G_GNUC_UNUSED,
-                           gpointer user_data G_GNUC_UNUSED)
-{
-    const gchar *authors[] = {
-        "Christopher Aillon <caillon@redhat.com>",
-        "Jonathan Blandford <jrb@redhat.com>",
-        "Colin Walters <walters@verbum.org>",
-        "Guido Günther <agx@sigxcpu.org>",
-        NULL
-    };
-
-    gtk_show_about_dialog (NULL,
-                           "authors", authors,
-                           "version", VERSION,
-                           "logo-icon-name", "krb-valid-ticket",
-                           "copyright",
-                           "Copyright (C) 2004,2005,2006 Red Hat, Inc.,\n"
-                           "2008,2009 Guido Günther",
-                           "website-label", PACKAGE " website",
-                           "website",
-                           "https://honk.sigxcpu.org/piki/projects/krb5-auth-dialog/",
-                           "license", "GNU General Public License Version 2",
-                           /* Translators: add the translators of your language here */
-                           "translator-credits", _("translator-credits"),
-                           NULL);
-}
-
-
-static void
-ka_applet_cb_show_help (GtkMenuItem *menuitem G_GNUC_UNUSED,
+ka_applet_show_help_cb (GtkMenuItem *menuitem G_GNUC_UNUSED,
                         gpointer user_data)
 {
     KaApplet *applet = KA_APPLET (user_data);
@@ -754,7 +710,7 @@ ka_applet_cb_show_help (GtkMenuItem *menuitem G_GNUC_UNUSED,
 
 
 static void
-ka_applet_cb_destroy_ccache (GtkMenuItem *menuitem G_GNUC_UNUSED,
+ka_applet_destroy_ccache_cb (GtkMenuItem *menuitem G_GNUC_UNUSED,
                              gpointer user_data)
 {
     KaApplet *applet = KA_APPLET (user_data);
@@ -763,10 +719,10 @@ ka_applet_cb_destroy_ccache (GtkMenuItem *menuitem G_GNUC_UNUSED,
 }
 
 static void
-ka_applet_cb_show_tickets (GtkMenuItem *menuitem G_GNUC_UNUSED,
+ka_applet_show_tickets_cb (GtkMenuItem *menuitem G_GNUC_UNUSED,
                            gpointer user_data G_GNUC_UNUSED)
 {
-    ka_tickets_dialog_run ();
+    ka_main_window_show ();
 }
 
 
@@ -784,7 +740,7 @@ ka_applet_create_context_menu (KaApplet *applet)
     menu_item =
         gtk_image_menu_item_new_with_mnemonic (_("Remove Credentials _Cache"));
     g_signal_connect (G_OBJECT (menu_item), "activate",
-                      G_CALLBACK (ka_applet_cb_destroy_ccache), applet);
+                      G_CALLBACK (ka_applet_destroy_ccache_cb), applet);
     image = gtk_image_new_from_stock (GTK_STOCK_CANCEL, GTK_ICON_SIZE_MENU);
     gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
@@ -794,26 +750,13 @@ ka_applet_create_context_menu (KaApplet *applet)
     /* Ticket dialog */
     menu_item = gtk_image_menu_item_new_with_mnemonic (_("_List Tickets"));
     g_signal_connect (G_OBJECT (menu_item), "activate",
-                      G_CALLBACK (ka_applet_cb_show_tickets), applet);
+                      G_CALLBACK (ka_applet_show_tickets_cb), applet);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
-    /* Preferences */
-    menu_item =
-        gtk_image_menu_item_new_from_stock (GTK_STOCK_PREFERENCES, NULL);
-    g_signal_connect (G_OBJECT (menu_item), "activate",
-                      G_CALLBACK (ka_applet_cb_preferences), applet);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
-    /* About item */
+    /* Help item */
     menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_HELP, NULL);
     g_signal_connect (G_OBJECT (menu_item), "activate",
-                      G_CALLBACK (ka_applet_cb_show_help), applet);
-    gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
-    /* About item */
-    menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_ABOUT, NULL);
-    g_signal_connect (G_OBJECT (menu_item), "activate",
-                      G_CALLBACK (ka_applet_cb_about_dialog), applet);
+                      G_CALLBACK (ka_applet_show_help_cb), applet);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
     ka_applet_menu_add_separator_item (menu);
@@ -821,7 +764,7 @@ ka_applet_create_context_menu (KaApplet *applet)
     /* Quit */
     menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT, NULL);
     g_signal_connect (G_OBJECT (menu_item), "activate",
-                      G_CALLBACK (ka_applet_cb_quit), applet);
+                      G_CALLBACK (ka_applet_quit_cb), applet);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
     gtk_widget_show_all (menu);
@@ -1015,13 +958,17 @@ ka_applet_create ()
         g_assert (error->message);
         g_error ("Failed to load UI XML: %s", error->message);
     }
+    gtk_builder_connect_signals (applet->priv->uixml, NULL);
+
     applet->priv->pwdialog = ka_pwdialog_create (applet->priv->uixml);
     g_return_val_if_fail (applet->priv->pwdialog != NULL, NULL);
 
     applet->priv->gconf = ka_gconf_init (applet);
     g_return_val_if_fail (applet->priv->gconf != NULL, NULL);
 
-    ka_tickets_dialog_create (applet->priv->uixml);
+    ka_main_window_create (applet, applet->priv->uixml);
+    ka_preferences_window_create (applet, applet->priv->uixml);
+
     applet->priv->loader = ka_plugin_loader_create (applet);
     g_return_val_if_fail (applet->priv->loader != NULL, NULL);
 
