@@ -40,7 +40,7 @@
 #include "ka-pwdialog.h"
 #include "ka-dbus.h"
 #include "ka-tools.h"
-#include "ka-tickets.h"
+#include "ka-main-window.h"
 
 #ifdef ENABLE_NETWORK_MANAGER
 #include <nm-client.h>
@@ -677,9 +677,9 @@ ka_unparse_name ()
 
 
 static void
-ccache_changed_cb (GFileMonitor * monitor G_GNUC_UNUSED,
-                   GFile * file,
-                   GFile * other_file G_GNUC_UNUSED,
+ccache_changed_cb (GFileMonitor *monitor G_GNUC_UNUSED,
+                   GFile *file,
+                   GFile *other_file G_GNUC_UNUSED,
                    GFileMonitorEvent event_type, gpointer data)
 {
     KaApplet *applet = KA_APPLET (data);
@@ -691,6 +691,7 @@ ccache_changed_cb (GFileMonitor * monitor G_GNUC_UNUSED,
     case G_FILE_MONITOR_EVENT_CHANGED:
         KA_DEBUG ("%s changed", ccache_name);
         credentials_expiring ((gpointer) applet);
+        g_signal_emit_by_name(applet, "krb-ccache-changed");
         break;
     default:
         KA_DEBUG ("%s unhandled event: %d", ccache_name, event_type);
@@ -1076,7 +1077,7 @@ main (int argc, char *argv[])
     GOptionContext *context;
     GError *error = NULL;
 
-    gboolean run_auto = FALSE, run_always = FALSE;
+    gboolean run_auto = FALSE;
 
     const char *help_msg =
         "Run '" PACKAGE
@@ -1084,9 +1085,6 @@ main (int argc, char *argv[])
     const GOptionEntry options[] = {
         {"auto", 'a', 0, G_OPTION_ARG_NONE, &run_auto,
          "Only run if an initialized ccache is found", NULL},
-        /* accepted for compatibility only */
-        {"always", 'A', 0, G_OPTION_ARG_NONE, &run_always,
-         "Always run (default)", NULL},
         {NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL}
     };
     GFileMonitor *monitor = NULL;
